<?php
if ( ! defined( 'ABSPATH' ) ) { 
	exit; // restict for direct access
}

/*
 * Plugin Name:       Addify - Password Protect Store
 * Plugin URI:        http://www.addifypro.com
 * Description:       Ability to set password on whole store,specfic categories or products.
 * Version:           2.5.0
 * Author:            Addify
 * Developed By:  	  Addify
 * Author URI:        http://www.addifypro.com
 * Support:		  	  http://www.addifypro.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Domain Path:       /languages
 * Text Domain:       addify_pps
 */


/**
 * Check if WooCommerce is installed and active.
 **/


if ( !in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

    
    function my_admin_notice() {

        // Deactivate the plugin
           deactivate_plugins(__FILE__);
            
          echo '<div id="message" class="error">
            <p><strong>Addify - Password Protect Store is inactive.</strong> The <a href="http://wordpress.org/extend/plugins/woocommerce/">WooCommerce plugin</a> must be active for this plugin to work. Please install &amp; activate WooCommerce »</p></div>';

}
add_action( 'admin_notices', 'my_admin_notice' );
}

if ( !class_exists( 'Addify_Password_Protected_Store' ) ) {

	class Addify_Password_Protected_Store {
		function __construct() {

			register_activation_hook( __FILE__, array( $this, 'pps_install_settings' ) );

			//register_deactivation_hook( __FILE__, array( $this, 'uninstall_settings' ));

			add_action( 'wp_loaded', array( $this, 'pps_main_init' ) );
			$this->pps_constant_vars();

			if ( is_admin() ) {
				require(addify_pps_plugindir.'pps_admin_class.php');
			} else {
				require(addify_pps_plugindir.'pps_front_class.php');
			}

			
		}


		function pps_main_init() {
	        if ( function_exists( 'load_plugin_textdomain' ) )
	            load_plugin_textdomain( 'addify_pps', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
	   	}
		
		function pps_constant_vars() {


            if ( !defined( 'addify_pps_url' ) )
                define( 'addify_pps_url', plugin_dir_url( __FILE__ ) );

            if ( !defined( 'addify_pps_basename' ) )
                define( 'addify_pps_basename', plugin_basename( __FILE__ ) );

            if ( ! defined( 'addify_pps_plugindir' ) )
                define( 'addify_pps_plugindir', plugin_dir_path( __FILE__ ) );
        }

        

        function pps_install_settings() {

        	global $wpdb;
		
			$wpdb->pps_passwords = $wpdb->prefix . 'pps_passwords';
			$wpdb->pps_password_rules = $wpdb->prefix . 'pps_password_rules';
			$wpdb->pps_password_data = $wpdb->prefix . 'pps_password_data';
			$wpdb->pps_password_order = $wpdb->prefix . 'pps_password_order';

			$this->create_tables();


        	$curr_post = $this->pps_the_slug_exists('pps-password-form');

            if (empty($curr_post) || $curr_post->post_name != 'pps-password-form') {
            // Create post object
			$my_post = array(
			  'post_title'    => 'Password Protected Form',
			  'post_name'    => 'pps-password-form',
			  'post_content'  => '',
			  'post_status'   => 'publish',
			  'post_author'   => 1,
			  'post_type'     => 'page',
			);

			// Insert the post into the database
			wp_insert_post( $my_post );
			}

			flush_rewrite_rules();
        }

		
        public function pps_the_slug_exists($post_name) {
            global $wpdb;

            $result = $wpdb->get_row("SELECT * FROM ".$wpdb->prefix."posts WHERE post_name = '".$post_name."'");
            return $result;
        }


        public function create_tables() {
            
			global $wpdb;
			
			$charset_collate = '';
		
			if ( !empty( $wpdb->charset ) )
				$charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
			if ( !empty( $wpdb->collate ) )
				$charset_collate .= " COLLATE $wpdb->collate";	
				
			if ( $wpdb->get_var( "SHOW TABLES LIKE '$wpdb->pps_passwords'" ) != $wpdb->pps_passwords ) {
				$sql1 = "CREATE TABLE " . $wpdb->pps_passwords . " (
									 p_id int(25) NOT NULL auto_increment,
									 rule_id text NULL,
									 password text NULL,
									 status varchar(255) NULL,
									
									 
									 PRIMARY KEY (p_id)
									 ) $charset_collate;";
		
			
			require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
				dbDelta( $sql1 );
			}


			if ( $wpdb->get_var( "SHOW TABLES LIKE '$wpdb->pps_password_rules'" ) != $wpdb->pps_password_rules ) {
				$sql2 = "CREATE TABLE " . $wpdb->pps_password_rules . " (
									 rule_id int(25) NOT NULL auto_increment,
									 rule_name text NULL,
									 rule_status varchar(255) NULL,
									 applied_to text NULL,
									 product_ids text NULL,
									 category_ids text NULL,
									 page_ids text NULL,
									 
									 PRIMARY KEY (rule_id)
									 ) $charset_collate;";
		
			
			require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
				dbDelta( $sql2 );
			}



			if ( $wpdb->get_var( "SHOW TABLES LIKE '$wpdb->pps_password_data'" ) != $wpdb->pps_password_data ) {
				$sql = "CREATE TABLE " . $wpdb->pps_password_data . " (
									 p_data_id int(25) NOT NULL auto_increment,
									 password_id varchar(255) NULL,
									 
									 ip_address varchar(255) NULL,
									 city varchar(255) NULL,
									 region varchar(255) NULL,
									 country varchar(255) NULL,
									 postal varchar(255) NULL,
									 org varchar(255) NULL,
									 date varchar(255) NULL,
									 time varchar(255) NULL,
									 browser varchar(255) NULL,

									 
									 PRIMARY KEY (p_data_id)
									 ) $charset_collate;";
		
			
			require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
				dbDelta( $sql );
			}



			if ( $wpdb->get_var( "SHOW TABLES LIKE '$wpdb->pps_password_order'" ) != $wpdb->pps_password_order ) {
				$sql22 = "CREATE TABLE " . $wpdb->pps_password_order . " (
									 o_id int(25) NOT NULL auto_increment,
									 password_id varchar(255) NULL,
									 order_id varchar(255) NULL,
									 product_name varchar(255) NULL,
									 purchased_quantity varchar(255) NULL,
									 price_total varchar(255) NULL,
									 customer_name varchar(255) NULL,
									 email varchar(255) NULL,
									 date_purchased varchar(255) NULL,
									 
									 PRIMARY KEY (o_id)
									 ) $charset_collate;";
		
			
			require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
				dbDelta( $sql22 );
			}
			


		}

		public function uninstall_settings() {

			$wpdb->pps_passwords = $wpdb->prefix . 'pps_passwords';
			$wpdb->pps_password_data = $wpdb->prefix . 'pps_password_data';


		    $sql1 = "DROP TABLE IF EXISTS $wpdb->pps_passwords";
		    $wpdb->query($sql1);

		    $sql2 = "DROP TABLE IF EXISTS $wpdb->pps_password_data";
		    $wpdb->query($sql2);
		}


		



	}

	new Addify_Password_Protected_Store();

}